summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_object.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
commit56160bf4dfe503631ef6373367b281f081bab2b4 (patch)
tree7fcea2ffd9c3420af999c3dcad0ed032eef93956 /khtml/rendering/render_object.h
parent13281e2856a2ef43bbab78c5528470309c23aa77 (diff)
downloadtdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.tar.gz
tdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 13281e2856a2ef43bbab78c5528470309c23aa77.
Diffstat (limited to 'khtml/rendering/render_object.h')
-rw-r--r--khtml/rendering/render_object.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/khtml/rendering/render_object.h b/khtml/rendering/render_object.h
index f7f772387..e403601d3 100644
--- a/khtml/rendering/render_object.h
+++ b/khtml/rendering/render_object.h
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
// repaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted
@@ -681,8 +681,8 @@ public:
// Used by collapsed border tables.
virtual void collectBorders(TQValueList<CollapsedBorderValue>& borderStyles);
- // force a complete repaint
- virtual void repaint(Priority p = NormalPriority) { if(m_parent) m_parent->repaint(p); }
+ // force a complete tqrepaint
+ virtual void tqrepaint(Priority p = NormalPriority) { if(m_parent) m_parent->tqrepaint(p); }
virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual unsigned int length() const { return 1; }
@@ -747,7 +747,7 @@ public:
virtual int leftmostPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
virtual int highestPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
- // recursively invalidate current layout
+ // recursively tqinvalidate current layout
// unused: void invalidateLayout();
virtual void calcVerticalMargins() {}
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
- // repaint and do not need a relayout
+ // tqrepaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted